@@ -35,13 +35,6 @@ typedef enum {
 	SECRET_SERVICE_LOAD_COLLECTIONS = 1 << 2,
 } SecretServiceFlags;
 
-typedef enum {
-	SECRET_SEARCH_NONE = 0,
-	SECRET_SEARCH_ALL = 1 << 1,
-	SECRET_SEARCH_UNLOCK = 1 << 2,
-	SECRET_SEARCH_LOAD_SECRETS = 1 << 3,
-} SecretSearchFlags;
-
 #define SECRET_TYPE_SERVICE            (secret_service_get_type ())
 #define SECRET_SERVICE(inst)           (G_TYPE_CHECK_INSTANCE_CAST ((inst), SECRET_TYPE_SERVICE, SecretService))
 #define SECRET_SERVICE_CLASS(class)    (G_TYPE_CHECK_CLASS_CAST ((class), SECRET_TYPE_SERVICE, SecretServiceClass))
@@ -75,21 +68,29 @@ struct _SecretServiceClass {
 
 	void        (* prompt_async)     (SecretService *self,
 	                                  SecretPrompt *prompt,
+	                                  const GVariantType *return_type,
 	                                  GCancellable *cancellable,
 	                                  GAsyncReadyCallback callback,
 	                                  gpointer user_data);
 
 	GVariant *  (* prompt_finish)    (SecretService *self,
 	                                  GAsyncResult *result,
-	                                  const GVariantType *return_type,
 	                                  GError **error);
 
+	GType       (* get_collection_gtype)  (SecretService *self);
+
+	GType       (* get_item_gtype)        (SecretService *self);
+
 	/*< private >*/
-	gpointer padding[16];
+	gpointer padding[14];
 };
 
 GType                secret_service_get_type                      (void) G_GNUC_CONST;
 
+GType                secret_service_get_collection_gtype          (SecretService *self);
+
+GType                secret_service_get_item_gtype                (SecretService *self);
+
 void                 secret_service_get                           (SecretServiceFlags flags,
                                                                    GCancellable *cancellable,
                                                                    GAsyncReadyCallback callback,
@@ -104,17 +105,17 @@ SecretService *      secret_service_get_sync                      (SecretService
 
 void                 secret_service_disconnect                    (void);
 
-void                 secret_service_new                           (GType service_gtype,
+void                 secret_service_open                          (GType service_gtype,
                                                                    const gchar *service_bus_name,
                                                                    SecretServiceFlags flags,
                                                                    GCancellable *cancellable,
                                                                    GAsyncReadyCallback callback,
                                                                    gpointer user_data);
 
-SecretService *      secret_service_new_finish                    (GAsyncResult *result,
+SecretService *      secret_service_open_finish                   (GAsyncResult *result,
                                                                    GError **error);
 
-SecretService *      secret_service_new_sync                      (GType service_gtype,
+SecretService *      secret_service_open_sync                     (GType service_gtype,
                                                                    const gchar *service_bus_name,
                                                                    SecretServiceFlags flags,
                                                                    GCancellable *cancellable,
@@ -160,13 +161,13 @@ GVariant *           secret_service_prompt_sync                   (SecretService
 
 void                 secret_service_prompt                        (SecretService *self,
                                                                    SecretPrompt *prompt,
+                                                                   const GVariantType *return_type,
                                                                    GCancellable *cancellable,
                                                                    GAsyncReadyCallback callback,
                                                                    gpointer user_data);
 
 GVariant *           secret_service_prompt_finish                 (SecretService *self,
                                                                    GAsyncResult *result,
-                                                                   const GVariantType *return_type,
                                                                    GError **error);
 
 void                 secret_service_search                        (SecretService *service,
@@ -262,18 +263,18 @@ SecretValue *        secret_service_lookup_sync                   (SecretService
                                                                    GCancellable *cancellable,
                                                                    GError **error);
 
-void                 secret_service_remove                        (SecretService *service,
+void                 secret_service_clear                         (SecretService *service,
                                                                    const SecretSchema *schema,
                                                                    GHashTable *attributes,
                                                                    GCancellable *cancellable,
                                                                    GAsyncReadyCallback callback,
                                                                    gpointer user_data);
 
-gboolean             secret_service_remove_finish                 (SecretService *service,
+gboolean             secret_service_clear_finish                  (SecretService *service,
                                                                    GAsyncResult *result,
                                                                    GError **error);
 
-gboolean             secret_service_remove_sync                   (SecretService *service,
+gboolean             secret_service_clear_sync                    (SecretService *service,
                                                                    const SecretSchema *schema,
                                                                    GHashTable *attributes,
                                                                    GCancellable *cancellable,
@@ -296,6 +297,8 @@ gboolean             secret_service_set_alias_sync                (SecretService
                                                                    GCancellable *cancellable,
                                                                    GError **error);
 
+G_DEFINE_AUTOPTR_CLEANUP_FUNC (SecretService, g_object_unref)
+
 G_END_DECLS
 
 #endif /* __SECRET_SERVICE_H___ */
